@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/clients/tools/ldappasswd.c,v 1.32.4.9 2000/08/26 17:04:34 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/clients/tools/ldappasswd.c,v 1.32.4.11 2000/09/13 20:19:45 kurt Exp $ */
 /*
  * Copyright 1998-2000 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -29,8 +29,8 @@ usage(const char *s)
 {
 	fprintf(stderr,
 "Change password of an LDAP user\n\n"
-"usage: %s [options] user\n"
-"  user: the identity of the user, normally a DN\n"
+"usage: %s [options] [user]\n"
+"  user: the autentication identity, commonly a DN\n"
 "Password change options:\n"
 "  -a secret  old password\n"
 "  -A         prompt for old password\n"
@@ -70,7 +70,7 @@ main( int argc, char *argv[] )
 	char	*ldaphost = NULL;
 	char	*ldapuri = NULL;
 
-	char	*dn = NULL;
+	char	*user = NULL;
 	char	*binddn = NULL;
 
 	struct berval passwd = { 0, NULL };
@@ -109,11 +109,8 @@ main( int argc, char *argv[] )
 
     prog = (prog = strrchr(argv[0], *LDAP_DIRSEP)) == NULL ? argv[0] : prog + 1;
 
-	if (argc == 1)
-		usage (argv[0]);
-
-	while( (i = getopt( argc, argv,
-		"Aa:Ss:" "Cd:D:h:H:InO:p:QRU:vw:WxX:Y:Z" )) != EOF )
+	while( (i = getopt( argc, argv, "Aa:Ss:"
+		"Cd:D:h:H:InO:p:QR:U:vw:WxX:Y:Z" )) != EOF )
 	{
 		switch (i) {
 		/* Password Options */
@@ -490,10 +487,6 @@ main( int argc, char *argv[] )
 		}
 	}
 
-	if( argc - optind != 1 ) {
-		usage( argv[0] );
-	} 
-
 	if (authmethod == -1) {
 #ifdef HAVE_CYRUS_SASL
 		authmethod = LDAP_AUTH_SASL;
@@ -502,15 +495,21 @@ main( int argc, char *argv[] )
 #endif
 	}
 
-	dn = strdup( argv[optind] );
+	if( argc - optind > 1 ) {
+		usage( argv[0] );
+	} else if ( argc - optind == 1 ) {
+		user = strdup( argv[optind] );
+	} else {
+		user = NULL;
+	}
 
 	if( want_oldpw && oldpw == NULL ) {
 		/* prompt for old password */
 		char *ckoldpw;
-		newpw = strdup(getpassphrase("Old password: "));
+		oldpw = strdup(getpassphrase("Old password: "));
 		ckoldpw = getpassphrase("Re-enter old password: ");
 
-		if( newpw== NULL || ckoldpw == NULL ||
+		if( oldpw== NULL || ckoldpw == NULL ||
 			strncmp( oldpw, ckoldpw, strlen(oldpw) ))
 		{
 			fprintf( stderr, "passwords do not match\n" );
@@ -532,16 +531,6 @@ main( int argc, char *argv[] )
 		}
 	}
 
-	if( binddn == NULL && dn != NULL ) {
-		binddn = dn;
-		dn = NULL;
-
-		if( passwd.bv_val == NULL ) {
-			passwd.bv_val = oldpw;
-			passwd.bv_len = oldpw == NULL ? 0 : strlen( oldpw );
-		}
-	}
-
 	if (want_bindpw && passwd.bv_val == NULL ) {
 		/* handle bind password */
 		fprintf( stderr, "Bind DN: %s\n", binddn );
@@ -569,20 +558,25 @@ main( int argc, char *argv[] )
 				ldaphost != NULL ? ldaphost : "<DEFAULT>",
 				ldapport );
 		}
+
 		ld = ldap_init( ldaphost, ldapport );
+		if( ld == NULL ) {
+			perror("ldapsearch: ldap_init");
+			return EXIT_FAILURE;
+		}
 
 	} else {
 		if ( verbose ) {
 			fprintf( stderr, "ldap_initialize( %s )\n",
 				ldapuri != NULL ? ldapuri : "<DEFAULT>" );
 		}
-		(void) ldap_initialize( &ld, ldapuri );
-	}
 
-	if( ld == NULL ) {
-		fprintf( stderr, "Could not create LDAP session handle (%d): %s\n",
-			rc, ldap_err2string(rc) );
-		return EXIT_FAILURE;
+		rc = ldap_initialize( &ld, ldapuri );
+		if( rc != LDAP_SUCCESS ) {
+			fprintf( stderr, "Could not create LDAP session handle (%d): %s\n",
+				rc, ldap_err2string(rc) );
+			return EXIT_FAILURE;
+		}
 	}
 
 	/* referrals */
@@ -656,7 +650,7 @@ main( int argc, char *argv[] )
 		}
 	}
 
-	if( dn != NULL || oldpw != NULL || newpw != NULL ) {
+	if( user != NULL || oldpw != NULL || newpw != NULL ) {
 		/* build change password control */
 		BerElement *ber = ber_alloc_t( LBER_USE_DER );
 
@@ -668,10 +662,10 @@ main( int argc, char *argv[] )
 
 		ber_printf( ber, "{" /*}*/ );
 
-		if( dn != NULL ) {
+		if( user != NULL ) {
 			ber_printf( ber, "ts",
-				LDAP_TAG_EXOP_X_MODIFY_PASSWD_ID, dn );
-			free(dn);
+				LDAP_TAG_EXOP_X_MODIFY_PASSWD_ID, user );
+			free(user);
 		}
 
 		if( oldpw != NULL ) {
