@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/clients/tools/ldapsearch.c,v 1.37.2.11 2000/09/05 17:54:37 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/clients/tools/ldapsearch.c,v 1.37.2.13 2000/09/13 20:19:45 kurt Exp $ */
 /*
  * Copyright 1998-2000 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -181,8 +181,8 @@ main( int argc, char **argv )
 
     prog = (prog = strrchr(argv[0], *LDAP_DIRSEP)) == NULL ? argv[0] : prog + 1;
 
-	while (( i = getopt( argc, argv,
-		"Aa:b:f:Ll:S:s:T:tuV:z:" "Cd:D:h:H:IkKMnO:p:P:QRU:vw:WxX:Y:Z")) != EOF )
+	while (( i = getopt( argc, argv, "Aa:b:f:Ll:S:s:T:tuV:z:"
+		"Cd:D:h:H:IkKMnO:p:P:QR:U:vw:WxX:Y:Z")) != EOF )
 	{
 	switch( i ) {
 	/* Search Options */
@@ -663,27 +663,31 @@ main( int argc, char **argv )
 	(void) SIGNAL( SIGPIPE, SIG_IGN );
 #endif
 
-
 	if( ( ldaphost != NULL || ldapport ) && ( ldapuri == NULL ) ) {
 		if ( verbose ) {
 			fprintf( stderr, "ldap_init( %s, %d )\n",
 				ldaphost != NULL ? ldaphost : "<DEFAULT>",
 				ldapport );
 		}
+
 		ld = ldap_init( ldaphost, ldapport );
+		if( ld == NULL ) {
+			perror("ldapsearch: ldap_init");
+			return EXIT_FAILURE;
+		}
 
 	} else {
 		if ( verbose ) {
 			fprintf( stderr, "ldap_initialize( %s )\n",
 				ldapuri != NULL ? ldapuri : "<DEFAULT>" );
 		}
-		(void) ldap_initialize( &ld, ldapuri );
-	}
 
-	if( ld == NULL ) {
-		fprintf( stderr, "Could not create LDAP session handle (%d): %s\n",
-			rc, ldap_err2string(rc) );
-		return EXIT_FAILURE;
+		rc = ldap_initialize( &ld, ldapuri );
+		if( rc != LDAP_SUCCESS ) {
+			fprintf( stderr, "Could not create LDAP session handle (%d): %s\n",
+				rc, ldap_err2string(rc) );
+			return EXIT_FAILURE;
+		}
 	}
 
 	if (deref != -1 &&
