@@ -22,7 +22,7 @@ lutil_sigaction(int sig, lutil_sig_t func)
 	action.sa_handler = func;
 	sigemptyset( &action.sa_mask );
 #ifdef SA_RESTART
-	action.sa_flags != SA_RESTART;
+	action.sa_flags |= SA_RESTART;
 #endif
 	
 	if( sigaction( sig, &action, &oaction ) != 0 ) {
