@@ -1,5 +1,5 @@
 /* bind.c - decode an ldap bind operation and pass it to a backend db */
-/* $OpenLDAP: pkg/ldap/servers/slapd/bind.c,v 1.38.2.7 2000/08/30 22:52:55 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/bind.c,v 1.38.2.8 2000/09/13 00:42:35 kurt Exp $ */
 /*
  * Copyright 1998-2000 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -53,30 +53,11 @@ do_bind(
 	mech = NULL;
 	cred.bv_val = NULL;
 
-	ldap_pvt_thread_mutex_lock( &conn->c_mutex );
-
 	/*
 	 * Force to connection to "anonymous" until bind succeeds.
 	 */
-
-	if ( conn->c_authmech != NULL ) {
-		free( conn->c_authmech );
-		conn->c_authmech = NULL;
-	}
-
-	if ( conn->c_cdn != NULL ) {
-		free( conn->c_cdn );
-		conn->c_cdn = NULL;
-	}
-
-	if ( conn->c_dn != NULL ) {
-		free( conn->c_dn );
-		conn->c_dn = NULL;
-	}
-
-	conn->c_authc_backend = NULL;
-	conn->c_authz_backend = NULL;
-
+	ldap_pvt_thread_mutex_lock( &conn->c_mutex );
+	connection2anonymous( conn );
 	ldap_pvt_thread_mutex_unlock( &conn->c_mutex );
 
 	if ( op->o_dn != NULL ) {
@@ -283,38 +264,78 @@ do_bind(
 		ldap_pvt_thread_mutex_unlock( &conn->c_mutex );
 	}
 
-	/* accept "anonymous" binds */
-	if ( cred.bv_len == 0 || ndn == NULL || *ndn == '\0' ) {
-		rc = LDAP_SUCCESS;
-		text = NULL;
+	if ( method == LDAP_AUTH_SIMPLE ) {
+		/* accept "anonymous" binds */
+		if ( cred.bv_len == 0 || ndn == NULL || *ndn == '\0' ) {
+			rc = LDAP_SUCCESS;
+			text = NULL;
 
-		if( cred.bv_len &&
-			( global_disallows & SLAP_DISALLOW_BIND_ANON_CRED ))
-		{
-			/* cred is not empty, disallow */
-			rc = LDAP_INVALID_CREDENTIALS;
+			if( cred.bv_len &&
+				( global_disallows & SLAP_DISALLOW_BIND_ANON_CRED ))
+			{
+				/* cred is not empty, disallow */
+				rc = LDAP_INVALID_CREDENTIALS;
 
-		} else if ( ndn != NULL && *ndn != '\0' &&
-			( global_disallows & SLAP_DISALLOW_BIND_ANON_DN ))
-		{
-			/* DN is not empty, disallow */
+			} else if ( ndn != NULL && *ndn != '\0' &&
+				( global_disallows & SLAP_DISALLOW_BIND_ANON_DN ))
+			{
+				/* DN is not empty, disallow */
+				rc = LDAP_UNWILLING_TO_PERFORM;
+				text = "unwilling to allow anonymous bind with non-empty DN";
+
+			} else if ( global_disallows & SLAP_DISALLOW_BIND_ANON ) {
+				/* disallow */
+				rc = LDAP_INAPPROPRIATE_AUTH;
+				text = "anonymous bind disallowed";
+			}
+
+			/*
+			 * we already forced connection to "anonymous",
+			 * just need to send success
+			 */
+			send_ldap_result( conn, op, rc,
+				NULL, text, NULL, NULL );
+			Debug( LDAP_DEBUG_TRACE, "do_bind: v%d anonymous bind\n",
+		   		version, 0, 0 );
+			goto cleanup;
+
+		} else if ( global_disallows & SLAP_DISALLOW_BIND_SIMPLE ) {
+			/* disallow simple authentication */
 			rc = LDAP_UNWILLING_TO_PERFORM;
-			text = "unwilling to allow anonymous bind with non-empty DN";
+			text = "unwilling to perform simple authentication";
 
-		} else if ( global_disallows & SLAP_DISALLOW_BIND_ANON ) {
-			/* disallow */
-			rc = LDAP_UNWILLING_TO_PERFORM;
-			text = "anonymous bind disallowed";
+			send_ldap_result( conn, op, rc,
+				NULL, text, NULL, NULL );
+			Debug( LDAP_DEBUG_TRACE,
+				"do_bind: v%d simple bind(%s) disallowed\n",
+		   		version, ndn, 0 );
+			goto cleanup;
 		}
 
-		/*
-		 * we already forced connection to "anonymous",
-		 * just need to send success
-		 */
+#ifdef LDAP_API_FEATURE_X_OPENLDAP_V2_KBIND
+	} else if ( method == LDAP_AUTH_KRBV41 || method == LDAP_AUTH_KRBV42 ) {
+		if ( global_disallows & SLAP_DISALLOW_BIND_KRBV4 ) {
+			/* disallow simple authentication */
+			rc = LDAP_UNWILLING_TO_PERFORM;
+			text = "unwilling to perform Kerberos V4 bind";
+
+			send_ldap_result( conn, op, rc,
+				NULL, text, NULL, NULL );
+			Debug( LDAP_DEBUG_TRACE, "do_bind: v%d Kerberos V4 bind\n",
+				version, 0, 0 );
+			goto cleanup;
+		}
+#endif
+
+	} else {
+		rc = LDAP_AUTH_UNKNOWN;
+		text = "unknown authentication method";
+
 		send_ldap_result( conn, op, rc,
 			NULL, text, NULL, NULL );
-		Debug( LDAP_DEBUG_TRACE, "do_bind: v%d anonymous bind\n",
-	   		version, 0, 0 );
+		Debug( LDAP_DEBUG_TRACE,
+			"do_bind: v%d unknown authentication method (%d)\n",
+			version, method, 0 );
 		goto cleanup;
 	}
 
