@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/servers/slapd/tools/slapadd.c,v 1.5.2.4 2000/08/21 02:40:27 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/tools/slapadd.c,v 1.5.2.5 2000/09/08 03:24:39 kurt Exp $ */
 /*
  * Copyright 1998-2000 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -67,6 +67,16 @@ main( int argc, char **argv )
 			break;
 		}
 
+		/* make sure the DN is valid */
+		if( e->e_ndn == '\0' ) {
+			fprintf( stderr, "%s: empty dn=\"%s\" (line=%d)\n",
+				progname, e->e_dn, lineno );
+			rc = EXIT_FAILURE;
+			entry_free( e );
+			if( continuemode ) continue;
+			break;
+		}
+
 		if( !noschemacheck ) {
 			/* check schema */
 			const char *text;
